@@ -8,78 +8,89 @@ build_time_vars = {'ABIFLAGS': '',
  'ALIGNOF_SIZE_T': 8,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
- 'AR': 'x86_64-pc-linux-gnu-ar',
+ 'AR': '/usr/lib/llvm/19/bin/llvm-ar',
  'ARFLAGS': 'rcs',
- 'BASECFLAGS': '-fno-strict-overflow -Wsign-compare',
+ 'BASECFLAGS': '-fno-strict-overflow -Wsign-compare -Wunreachable-code',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python3.12',
  'BLDLIBRARY': '-L. -lpython3.12',
- 'BLDSHARED': 'x86_64-pc-linux-gnu-gcc -shared',
+ 'BLDSHARED': 'clang -shared',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-pc-linux-gnu',
  'BUILD_SCRIPTS_DIR': 'build/scripts-3.12',
  'BYTESTR_DEPS': '\\',
- 'CC': 'x86_64-pc-linux-gnu-gcc',
+ 'CC': 'clang',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG',
+ 'CFLAGS': '-fno-strict-overflow -Wsign-compare -Wunreachable-code -DNDEBUG',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
- 'CFLAGS_NODIST': '',
  'CODECS_COMMON_HEADERS': './Modules/cjkcodecs/multibytecodec.h '
                           './Modules/cjkcodecs/cjkcodecs.h',
- 'COMPILEALL_OPTS': '-j2',
+ 'COMPILEALL_OPTS': '-j24',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
- 'CONFIGURE_CFLAGS_NODIST': '-march=x86-64 -O2 -pipe -std=c11 -Wextra '
-                            '-Wno-unused-parameter '
+ 'CONFIGURE_CFLAGS_NODIST': '-O3 -pipe -march=znver2 -mtune=znver3 '
+                            '-fpermissive -frecord-command-line '
+                            '-fcolor-diagnostics '
+                            '-Wno-error=implicit-function-declaration '
+                            '-flto=thin -fwrapv -ffat-lto-objects -flto=thin '
+                            '-g -std=c11 -Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/include/ncursesw',
  'CONFIGURE_LDFLAGS': '',
- 'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed '
-                             '-Wl,-z,pack-relative-relocs',
- 'CONFIGURE_LDFLAGS_NOLTO': '',
+ 'CONFIGURE_LDFLAGS_NODIST': '-v -Wl,-O1 -Wl,--as-needed '
+                             '-Wl,-z,pack-relative-relocs -Wl,--as-needed '
+                             '-Wl,-O2 -Wl,--as-needed '
+                             '-Wl,-z,pack-relative-relocs -Wl,-z,relro '
+                             '-Wl,-z,now -flto=thin -g',
+ 'CONFIGURE_LDFLAGS_NOLTO': '-flto=thin',
  'CONFIG_ARGS': "'--prefix=/usr' '--build=x86_64-pc-linux-gnu' "
                 "'--host=x86_64-pc-linux-gnu' '--mandir=/usr/share/man' "
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
                 "'--sysconfdir=/etc' '--localstatedir=/var/lib' "
                 "'--datarootdir=/usr/share' "
-                "'--docdir=/usr/share/doc/python-3.12.10_p1' "
-                "'--htmldir=/usr/share/doc/python-3.12.10_p1/html' "
+                "'--docdir=/usr/share/doc/python-3.12.10' "
+                "'--htmldir=/usr/share/doc/python-3.12.10/html' "
                 "'--libdir=/usr/lib64' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
                 "'--mandir=/usr/share/man' '--with-computed-gotos' "
-                "'--with-dbmliborder=gdbm' '--with-libc=' "
+                "'--with-dbmliborder=' '--with-libc=' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'--without-lto' '--with-system-expat' "
                 "'--with-system-libmpdec' '--with-platlibdir=lib' "
                 "'--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
-                "'--without-assertions' '--disable-optimizations' "
-                "'--with-readline=readline' '--without-valgrind' "
+                "'--without-assertions' '--enable-optimizations' "
+                "'--with-readline=readline' '--without-valgrind' '--with-lto' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' "
-                "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' 'CFLAGS=' "
-                "'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw'",
+                "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' 'CC=clang' "
+                "'CFLAGS=' 'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw' "
+                "'CPP=clang-cpp' 'PROFILE_TASK=-m test -j24 --pgo-extended "
+                '-u-network --timeout 1200 -x test_pretty_print -x test_dtrace '
+                '-x test_asyncio -x test_concurrent_futures -x '
+                'test_httpservers -x test_logging -x test_multiprocessing_fork '
+                "-x test_socket -x test_xmlrpc -x test_tools'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.12.10_p1/work/Python-3.12.10/coverage.info',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.12.10/work/Python-3.12.10/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.12.10_p1/work/Python-3.12.10/lcov-report',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.12.10/work/Python-3.12.10/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
- 'CXX': 'x86_64-pc-linux-gnu-g++',
+ 'CXX': 'clang++',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
  'DEEPFREEZE_DEPS': './Tools/build/deepfreeze.py _bootstrap_python '
                     './Programs/_freeze_module.py \\',
@@ -186,7 +197,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CURSES_TYPEAHEAD': 1,
  'HAVE_CURSES_USE_ENV': 1,
  'HAVE_CURSES_WCHGAT': 1,
- 'HAVE_DB_H': 0,
+ 'HAVE_DB_H': 1,
  'HAVE_DECL_RTLD_DEEPBIND': 1,
  'HAVE_DECL_RTLD_GLOBAL': 1,
  'HAVE_DECL_RTLD_LAZY': 1,
@@ -260,7 +271,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GCC_UINT128_T': 1,
  'HAVE_GDBM_DASH_NDBM_H': 0,
  'HAVE_GDBM_H': 1,
- 'HAVE_GDBM_NDBM_H': 1,
+ 'HAVE_GDBM_NDBM_H': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETEGID': 1,
@@ -330,7 +341,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
  'HAVE_LIBB2': 1,
- 'HAVE_LIBDB': 0,
+ 'HAVE_LIBDB': 1,
  'HAVE_LIBDL': 1,
  'HAVE_LIBDLD': 0,
  'HAVE_LIBIEEE': 0,
@@ -625,42 +636,51 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.12',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.12',
- 'INSTALL': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c',
- 'INSTALL_DATA': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c '
+ 'INSTALL': '/usr/lib/portage/python3.12/ebuild-helpers/xattr/install -c',
+ 'INSTALL_DATA': '/usr/lib/portage/python3.12/ebuild-helpers/xattr/install -c '
                  '-m 644',
- 'INSTALL_PROGRAM': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
+ 'INSTALL_PROGRAM': '/usr/lib/portage/python3.12/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/usr/lib/portage/python3.12/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/usr/lib/portage/python3.12/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.12.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'x86_64-pc-linux-gnu-g++ -shared',
+ 'LDCXXSHARED': 'clang++ -shared',
  'LDFLAGS': '',
- 'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.12.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'x86_64-pc-linux-gnu-gcc -shared',
+ 'LDSHARED': 'clang -shared',
  'LDVERSION': '3.12',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python3.12',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG '
-                    '-march=x86-64 -O2 -pipe -std=c11 -Wextra '
+ 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -Wunreachable-code '
+                    '-DNDEBUG -O3 -pipe -march=znver2 -mtune=znver3 '
+                    '-fpermissive -frecord-command-line -fcolor-diagnostics '
+                    '-Wno-error=implicit-function-declaration -flto=thin '
+                    '-fwrapv -ffat-lto-objects -flto=thin -g -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                    '-fvisibility=hidden '
+                    '-fprofile-instr-use=/var/tmp/portage/dev-lang/python-3.12.10/work/Python-3.12.10/code.profclangd '
+                    '-I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
-                   '-fno-strict-overflow -Wsign-compare -DNDEBUG -march=x86-64 '
-                   '-O2 -pipe -std=c11 -Wextra -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
+                   '-fno-strict-overflow -Wsign-compare -Wunreachable-code '
+                   '-DNDEBUG -O3 -pipe -march=znver2 -mtune=znver3 '
+                   '-fpermissive -frecord-command-line -fcolor-diagnostics '
+                   '-Wno-error=implicit-function-declaration -flto=thin '
+                   '-fwrapv -ffat-lto-objects -flto=thin -g -std=c11 -Wextra '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden '
+                   '-fprofile-instr-use=/var/tmp/portage/dev-lang/python-3.12.10/work/Python-3.12.10/code.profclangd '
                    '-I./Include/internal -I. -I./Include '
                    '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBHACL_HEADERS': '\\',
@@ -670,11 +690,16 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
-                    '-fno-strict-overflow -Wsign-compare -DNDEBUG '
-                    '-march=x86-64 -O2 -pipe -std=c11 -Wextra '
+                    '-fno-strict-overflow -Wsign-compare -Wunreachable-code '
+                    '-DNDEBUG -O3 -pipe -march=znver2 -mtune=znver3 '
+                    '-fpermissive -frecord-command-line -fcolor-diagnostics '
+                    '-Wno-error=implicit-function-declaration -flto=thin '
+                    '-fwrapv -ffat-lto-objects -flto=thin -g -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                    '-fvisibility=hidden '
+                    '-fprofile-instr-use=/var/tmp/portage/dev-lang/python-3.12.10/work/Python-3.12.10/code.profclangd '
+                    '-I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
@@ -689,15 +714,17 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-ldl',
  'LIBSUBDIRS': 'asyncio \\',
- 'LINKCC': 'x86_64-pc-linux-gnu-gcc',
+ 'LINKCC': 'clang',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LINK_PYTHON_DEPS': 'libpython3.12.so libpython3.so',
  'LINK_PYTHON_OBJS': '-L. -lpython3.12',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
- 'LLVM_PROF_FILE': '',
- 'LLVM_PROF_MERGER': 'true',
+ 'LLVM_PROF_FILE': 'LLVM_PROFILE_FILE="$(shell pwd)/code-%p.profclangr"',
+ 'LLVM_PROF_MERGER': '/usr/lib/llvm/19/bin/llvm-profdata merge '
+                     '-output="$(shell pwd)/code.profclangd" "$(shell '
+                     'pwd)"/*.profclangr',
  'LN': 'ln',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
@@ -713,22 +740,22 @@ build_time_vars = {'ABIFLAGS': '',
                    '_json  _lsprof  _opcode  _pickle  _queue  _random  '
                    '_struct  _xxsubinterpreters  _xxinterpchannels  _zoneinfo  '
                    'audioop  math  cmath  _statistics  _datetime  _decimal  '
-                   'binascii  _bz2  _lzma  zlib  _dbm  _gdbm  readline  _md5  '
-                   '_sha1  _sha2  _sha3  _blake2  pyexpat  _elementtree  '
-                   '_codecs_cn  _codecs_hk  _codecs_iso2022  _codecs_jp  '
-                   '_codecs_kr  _codecs_tw  _multibytecodec  unicodedata  '
-                   '_crypt  fcntl  grp  mmap  ossaudiodev  _posixsubprocess  '
-                   'resource  select  _socket  spwd  syslog  termios  '
-                   '_posixshmem  _multiprocessing  _ctypes  _curses  '
-                   '_curses_panel  _sqlite3  _ssl  _hashlib  _uuid  xxsubtype  '
-                   '_xxtestfuzz  _testbuffer  _testinternalcapi  _testcapi  '
-                   '_testclinic  _testimportmultiple  _testmultiphase  '
-                   '_testsinglephase  _ctypes_test  xxlimited  xxlimited_35  '
-                   'atexit  faulthandler  posix  _signal  _tracemalloc  '
-                   '_codecs  _collections  errno  _io  itertools  _sre  '
-                   '_thread  time  _typing  _weakref  _abc  _functools  '
-                   '_locale  _operator  _stat  _symtable  pwd',
- 'MODDISABLED_NAMES': 'nis  _tkinter',
+                   'binascii  _bz2  _lzma  zlib  readline  _md5  _sha1  _sha2  '
+                   '_sha3  _blake2  pyexpat  _elementtree  _codecs_cn  '
+                   '_codecs_hk  _codecs_iso2022  _codecs_jp  _codecs_kr  '
+                   '_codecs_tw  _multibytecodec  unicodedata  _crypt  fcntl  '
+                   'grp  mmap  ossaudiodev  _posixsubprocess  resource  '
+                   'select  _socket  spwd  syslog  termios  _posixshmem  '
+                   '_multiprocessing  _ctypes  _curses  _curses_panel  '
+                   '_sqlite3  _ssl  _hashlib  _uuid  xxsubtype  _xxtestfuzz  '
+                   '_testbuffer  _testinternalcapi  _testcapi  _testclinic  '
+                   '_testimportmultiple  _testmultiphase  _testsinglephase  '
+                   '_ctypes_test  xxlimited  xxlimited_35  atexit  '
+                   'faulthandler  posix  _signal  _tracemalloc  _codecs  '
+                   '_collections  errno  _io  itertools  _sre  _thread  time  '
+                   '_typing  _weakref  _abc  _functools  _locale  _operator  '
+                   '_stat  _symtable  pwd',
+ 'MODDISABLED_NAMES': 'nis  _gdbm _dbm  _tkinter',
  'MODLIBS': '',
  'MODOBJS': 'Modules/atexitmodule.o  Modules/faulthandler.o  '
             'Modules/posixmodule.o  Modules/signalmodule.o  '
@@ -747,8 +774,8 @@ build_time_vars = {'ABIFLAGS': '',
                     '_lsprof _opcode _pickle _queue _random _struct '
                     '_xxsubinterpreters _xxinterpchannels _zoneinfo audioop '
                     'math cmath _statistics _datetime _decimal binascii _bz2 '
-                    '_lzma zlib _dbm _gdbm readline _md5 _sha1 _sha2 _sha3 '
-                    '_blake2 pyexpat _elementtree _codecs_cn _codecs_hk '
+                    '_lzma zlib readline _md5 _sha1 _sha2 _sha3 _blake2 '
+                    'pyexpat _elementtree _codecs_cn _codecs_hk '
                     '_codecs_iso2022 _codecs_jp _codecs_kr _codecs_tw '
                     '_multibytecodec unicodedata _crypt fcntl grp mmap '
                     'ossaudiodev _posixsubprocess resource select _socket spwd '
@@ -887,9 +914,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__CURSES_STATE': 'yes',
  'MODULE__DATETIME_LDFLAGS': '-lm',
  'MODULE__DATETIME_STATE': 'yes',
- 'MODULE__DBM_CFLAGS': '-DUSE_GDBM_COMPAT',
- 'MODULE__DBM_LDFLAGS': '-lgdbm_compat',
- 'MODULE__DBM_STATE': 'yes',
+ 'MODULE__DBM_STATE': 'disabled',
  'MODULE__DECIMAL_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1',
  'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h',
  'MODULE__DECIMAL_LDFLAGS': '-lmpdec',
@@ -898,9 +923,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__ELEMENTTREE_DEPS': './Modules/pyexpat.c',
  'MODULE__ELEMENTTREE_STATE': 'yes',
  'MODULE__FUNCTOOLS_LDFLAGS': '',
- 'MODULE__GDBM_CFLAGS': '',
- 'MODULE__GDBM_LDFLAGS': '-lgdbm',
- 'MODULE__GDBM_STATE': 'yes',
+ 'MODULE__GDBM_STATE': 'disabled',
  'MODULE__HASHLIB_CFLAGS': '',
  'MODULE__HASHLIB_DEPS': './Modules/hashlib.h',
  'MODULE__HASHLIB_LDFLAGS': '-lcrypto',
@@ -984,9 +1007,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__TESTINTERNALCAPI_STATE': 'yes',
  'MODULE__TESTMULTIPHASE_STATE': 'yes',
  'MODULE__THREAD_LDFLAGS': '',
- 'MODULE__TKINTER_CFLAGS': '-Wno-strict-prototypes -DWITH_APPINIT=1',
- 'MODULE__TKINTER_LDFLAGS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
- 'MODULE__TKINTER_STATE': 'yes',
+ 'MODULE__TKINTER_STATE': 'missing',
  'MODULE__TRACEMALLOC_LDFLAGS': '',
  'MODULE__TYPING_LDFLAGS': '',
  'MODULE__TYPING_STATE': 'yes',
@@ -1014,12 +1035,16 @@ build_time_vars = {'ABIFLAGS': '',
  'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/tokenizer.o',
  'PEGEN_HEADERS': '\\',
  'PEGEN_OBJS': '\\',
- 'PGO_PROF_GEN_FLAG': '-fprofile-generate',
- 'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
+ 'PGO_PROF_GEN_FLAG': '-fprofile-instr-generate',
+ 'PGO_PROF_USE_FLAG': '-fprofile-instr-use="$(shell pwd)/code.profclangd"',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo --timeout=1200',
+ 'PROFILE_TASK': '-m test -j24 --pgo-extended -u-network --timeout 1200 -x '
+                 'test_pretty_print -x test_dtrace -x test_asyncio -x '
+                 'test_concurrent_futures -x test_httpservers -x test_logging '
+                 '-x test_multiprocessing_fork -x test_socket -x test_xmlrpc '
+                 '-x test_tools',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -1038,47 +1063,75 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG '
-                             '-march=x86-64 -O2 -pipe -std=c11 -Wextra '
-                             '-Wno-unused-parameter '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
+                             '-Wunreachable-code -DNDEBUG -O3 -pipe '
+                             '-march=znver2 -mtune=znver3 -fpermissive '
+                             '-frecord-command-line -fcolor-diagnostics '
+                             '-Wno-error=implicit-function-declaration '
+                             '-flto=thin -fwrapv -ffat-lto-objects -flto=thin '
+                             '-g -std=c11 -Wextra -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden  -I./Include/internal -I. '
-                             '-I./Include -I/usr/include/ncursesw -fPIC '
+                             '-fvisibility=hidden '
+                             '-fprofile-instr-use=/var/tmp/portage/dev-lang/python-3.12.10/work/Python-3.12.10/code.profclangd '
+                             '-I./Include/internal -I. -I./Include '
+                             '-I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG',
- 'PY_CFLAGS_NODIST': '-march=x86-64 -O2 -pipe -std=c11 -Wextra '
+ 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -Wunreachable-code -DNDEBUG',
+ 'PY_CFLAGS_NODIST': '-O3 -pipe -march=znver2 -mtune=znver3 -fpermissive '
+                     '-frecord-command-line -fcolor-diagnostics '
+                     '-Wno-error=implicit-function-declaration -flto=thin '
+                     '-fwrapv -ffat-lto-objects -flto=thin -g -std=c11 -Wextra '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden  -I./Include/internal',
+                     '-fvisibility=hidden '
+                     '-fprofile-instr-use=/var/tmp/portage/dev-lang/python-3.12.10/work/Python-3.12.10/code.profclangd '
+                     '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -march=x86-64 '
-                   '-O2 -pipe -std=c11 -Wextra -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
+ 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -Wunreachable-code '
+                   '-DNDEBUG -O3 -pipe -march=znver2 -mtune=znver3 '
+                   '-fpermissive -frecord-command-line -fcolor-diagnostics '
+                   '-Wno-error=implicit-function-declaration -flto=thin '
+                   '-fwrapv -ffat-lto-objects -flto=thin -g -std=c11 -Wextra '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden '
+                   '-fprofile-instr-use=/var/tmp/portage/dev-lang/python-3.12.10/work/Python-3.12.10/code.profclangd '
                    '-I./Include/internal -I. -I./Include '
                    '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs',
+ 'PY_CORE_LDFLAGS': '-v -Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
+                    '-Wl,--as-needed -Wl,-O2 -Wl,--as-needed '
+                    '-Wl,-z,pack-relative-relocs -Wl,-z,relro -Wl,-z,now '
+                    '-flto=thin -g',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 1,
  'PY_LDFLAGS': '',
- 'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs',
- 'PY_LDFLAGS_NOLTO': '',
+ 'PY_LDFLAGS_NODIST': '-v -Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
+                      '-Wl,--as-needed -Wl,-O2 -Wl,--as-needed '
+                      '-Wl,-z,pack-relative-relocs -Wl,-z,relro -Wl,-z,now '
+                      '-flto=thin -g',
+ 'PY_LDFLAGS_NOLTO': '-flto=thin',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG '
-                        '-march=x86-64 -O2 -pipe -std=c11 -Wextra '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
-                        '-Wstrict-prototypes '
+ 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
+                        '-Wunreachable-code -DNDEBUG -O3 -pipe -march=znver2 '
+                        '-mtune=znver3 -fpermissive -frecord-command-line '
+                        '-fcolor-diagnostics '
+                        '-Wno-error=implicit-function-declaration -flto=thin '
+                        '-fwrapv -ffat-lto-objects -flto=thin -g -std=c11 '
+                        '-Wextra -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden  -I./Include/internal -I. '
-                        '-I./Include -I/usr/include/ncursesw -fPIC',
- 'PY_SUPPORT_TIER': 1,
+                        '-fvisibility=hidden '
+                        '-fprofile-instr-use=/var/tmp/portage/dev-lang/python-3.12.10/work/Python-3.12.10/code.profclangd '
+                        '-I./Include/internal -I. -I./Include '
+                        '-I/usr/include/ncursesw -fPIC',
+ 'PY_SUPPORT_TIER': 2,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -1089,7 +1142,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.10_p1/work/Python-3.12.10',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.10/work/Python-3.12.10',
  'SCRIPTDIR': '/usr/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1121,8 +1174,6 @@ build_time_vars = {'ABIFLAGS': '',
                'Modules/_bz2.cpython-312-x86_64-linux-gnu.so '
                'Modules/_lzma.cpython-312-x86_64-linux-gnu.so '
                'Modules/zlib.cpython-312-x86_64-linux-gnu.so '
-               'Modules/_dbm.cpython-312-x86_64-linux-gnu.so '
-               'Modules/_gdbm.cpython-312-x86_64-linux-gnu.so '
                'Modules/readline.cpython-312-x86_64-linux-gnu.so '
                'Modules/_md5.cpython-312-x86_64-linux-gnu.so '
                'Modules/_sha1.cpython-312-x86_64-linux-gnu.so '
@@ -1213,10 +1264,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.10_p1/work/Python-3.12.10 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.10/work/Python-3.12.10 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.10_p1/work/Python-3.12.10 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.10/work/Python-3.12.10 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1246,8 +1297,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.12.10_p1/work/Python-3.12.10',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.12.10_p1/work/Python-3.12.10',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.12.10/work/Python-3.12.10',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.12.10/work/Python-3.12.10',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
